
from random import shuffle, random, randint
import math


# function to create a list of experiment numbers
# params
#   minimum: min experiment number
#   num:     number of experiments
def exp_nums(minimum=0, num=50):
    nums = [i for i in range(minimum + num - 1)]
    return nums


# function to create a list of data
#   dtype:   'i' for integers, 'f' for floats
#   minimum: minimum allowable data value
#   maximum: maximum allowable data value
#   num:     number of data values to generate
def data_gen(dtype='i', minimum=100, maximum=1000, num=50):
    if dtype == 'i':
        vals = [randint(minimum, maximum) for _ in range(num)]
    elif dtype == 'f':
        vals = [random() * (maximum - minimum) + minimum for _ in range(num)]
    else:
        print('Incorrect data type: use i or f\n')
        vals = []
        
    return vals


def data_sort(nums, i_data1, i_data2, f_data, rev_order=False):
    combined = list(zip(nums, i_data1, i_data2, f_data))
    combined.sort(key=lambda e: (e[1], e[3]), reverse=rev_order)
    nums = [e[0] for e in combined]
    i_data1 = [e[1] for e in combined]
    i_data2 = [e[2] for e in combined]
    f_data = [e[3] for e in combined]
    return nums, i_data1, i_data2, f_data

    
def main():
    # prompt user and read values
    data_size = int(input('Enter the number of experiments: '))

    # call functions to generate values
    exps = exp_nums(minimum=0, num=data_size)
    d1 = data_gen(num=data_size)
    d2 = data_gen(num=data_size)
    d3 = data_gen(dtype='f', minimum=0, maximum=1, num=data_size)
    
    print()
    print('Data before sorting:')
    
    for i in range(len(exps)):
        print('  {:5d}  {:10.6f}  {:5d}  {:5d}'.format(exps[i], d3[i], d1[i], d2[i]))
    print()
    
    exps, d1, d2, d3 = data_sort(exps, d1, d2, d3)
    
    print('Data after sorting:')
    
    for i in range(len(exps)):
        print('  {:5d}  {:10.6f}  {:5d}  {:5d}'.format(exps[i], d3[i], d1[i], d2[i]))
    print()
    
    
if __name__ == '__main__':
    main()
    